@@ -34,7 +34,8 @@
 #include "sol.h"
 #include "events.h"
 #include "draw.h"
-#include "gnome.h"
+#include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "slot.h"
 #include "card.h"
 #include "cscmi.h"
@@ -472,6 +473,8 @@ int main (int argc, char *argv [])
   aisleriot_opts[0].descrip = N_("Variation on game rules");
   aisleriot_opts[0].argDescrip = N_("NAME");
 
+  gnome_score_init ("Aisleriot");
+
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
@@ -480,7 +483,8 @@ int main (int argc, char *argv [])
 
   gtk_widget_push_colormap (gdk_imlib_get_colormap ());
   gtk_widget_push_visual (gdk_imlib_get_visual ());
-  
+
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-aisleriot.png");
   splash_new ();
 
   splash_update (_("Initializing scheme..."), 0.20);
